@@ -447,7 +447,17 @@ int nvidia_mmap_helper(
             addr  = mmap_start;
             
             // Needed for the linux kernel for mapping compound pages
-            nv_vm_flags_set(vma, VM_MIXEDMAP);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 15, 0)
+            // Rel. commit "mm: uninline the main body of vma_start_write()" (Suren Baghdasaryan, 13 Feb 2025)
+            // Since Linux 6.15, vm_flags_set and vm_flags_clear call a GPL-only symbol
+            // for locking (__vma_start_write), which can't be called from non-GPL code.
+            // However, it appears all uses on the driver are on VMAs being initially
+            // mapped / which are already locked, so we can use vm_flags_reset, which
+            // doesn't lock the VMA, but rather just asserts it is already write-locked.
+            vm_flags_reset(vma, vma->vm_flags | VM_MIXEDMAP);
+#else
+            vm_flags_set(vma, VM_MIXEDMAP);
+#endif
 
             for (j = 0; j < pages; j++)
             {
@@ -471,7 +481,17 @@ int nvidia_mmap_helper(
             }
         }
 
-        nv_vm_flags_set(vma, VM_IO);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 15, 0)
+        // Rel. commit "mm: uninline the main body of vma_start_write()" (Suren Baghdasaryan, 13 Feb 2025)
+        // Since Linux 6.15, vm_flags_set and vm_flags_clear call a GPL-only symbol
+        // for locking (__vma_start_write), which can't be called from non-GPL code.
+        // However, it appears all uses on the driver are on VMAs being initially
+        // mapped / which are already locked, so we can use vm_flags_reset, which
+        // doesn't lock the VMA, but rather just asserts it is already write-locked.
+        vm_flags_reset(vma, vma->vm_flags | VM_IO);
+#else
+        vm_flags_set(vma, VM_IO);
+#endif
     }
     else
     {
@@ -533,15 +553,37 @@ int nvidia_mmap_helper(
 
         NV_PRINT_AT(NV_DBG_MEMINFO, at);
 
-        nv_vm_flags_set(vma, VM_IO | VM_LOCKED | VM_RESERVED);
-        nv_vm_flags_set(vma, VM_DONTEXPAND | VM_DONTDUMP);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 15, 0)
+        // Rel. commit "mm: uninline the main body of vma_start_write()" (Suren Baghdasaryan, 13 Feb 2025)
+        // Since Linux 6.15, vm_flags_set and vm_flags_clear call a GPL-only symbol
+        // for locking (__vma_start_write), which can't be called from non-GPL code.
+        // However, it appears all uses on the driver are on VMAs being initially
+        // mapped / which are already locked, so we can use vm_flags_reset, which
+        // doesn't lock the VMA, but rather just asserts it is already write-locked.
+        vm_flags_reset(vma, vma->vm_flags | (VM_IO | VM_LOCKED | VM_RESERVED));
+        vm_flags_reset(vma, vma->vm_flags | (VM_DONTEXPAND | VM_DONTDUMP));
+#else
+        vm_flags_set(vma, VM_IO | VM_LOCKED | VM_RESERVED);
+        vm_flags_set(vma, VM_DONTEXPAND | VM_DONTDUMP);
+#endif
     }
 
     if ((prot & NV_PROTECT_WRITEABLE) == 0)
     {
         vma->vm_page_prot = NV_PGPROT_READ_ONLY(vma->vm_page_prot);
-        nv_vm_flags_clear(vma, VM_WRITE);
-        nv_vm_flags_clear(vma, VM_MAYWRITE);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 15, 0)
+        // Rel. commit "mm: uninline the main body of vma_start_write()" (Suren Baghdasaryan, 13 Feb 2025)
+        // Since Linux 6.15, vm_flags_set and vm_flags_clear call a GPL-only symbol
+        // for locking (__vma_start_write), which can't be called from non-GPL code.
+        // However, it appears all uses on the driver are on VMAs being initially
+        // mapped / which are already locked, so we can use vm_flags_reset, which
+        // doesn't lock the VMA, but rather just asserts it is already write-locked.
+        vm_flags_reset(vma, vma->vm_flags & ~VM_WRITE);
+        vm_flags_reset(vma, vma->vm_flags & ~VM_MAYWRITE);
+#else
+        vm_flags_clear(vma, VM_WRITE);
+        vm_flags_clear(vma, VM_MAYWRITE);
+#endif
     }
 
     vma->vm_ops = &nv_vm_ops;
